@@ -183,9 +183,12 @@ class Disclosure(Mongo):
 
         # delete unused attributes
         del p['_id']
-        del p['adp_sync_date']
-        del p['id']
-        del p['person_type']
+        if "adp_sync_date" in p:
+            del p['adp_sync_date']
+        if "id" in p:
+            del p['id']
+        if "person_type" in p:
+            del p['person_type']
 
         # check for future hire
         today = datetime.date.today().strftime('%Y-%m-%d')
